@@ -16,7 +16,7 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "config.h"
-static  char    rcsid2[] = "@(#) $Revision: 1,8 $";
+static  char    rcsid2[] = "@(#) $Revision: 1.9 $";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -94,7 +94,8 @@ GtkListStore    *jlist_store,
 
 extern  struct  macromenitem    jobmacs[], varmacs[];
 
-int             Dirty;
+char            xml_format;
+char            Dirty;
 
 static void  cb_about();
 static void  cb_quit();
@@ -398,7 +399,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 {
         GtkWidget  *vbox;
 
-        versionprint(argv, "$Revision: 1,8 $", 0);
+        versionprint(argv, "$Revision: 1.9 $", 0);
 
         if  ((progname = strrchr(argv[0], '/')))
                 progname++;
